package tech.riemann.bidding.component.impl;

import java.io.IOException;
import java.time.LocalDate;
import java.util.List;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.nutz.lang.Lang;
import org.nutz.log.Log;
import org.nutz.log.Logs;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 
 */
@Component
@RequiredArgsConstructor
public class BOCQNoticeCollector extends NoticeCollector {

	private final NoticeRepository noticeRepository;

	private static final Log logger = Logs.get();
	private final ScheduledLogRepository scheduledLogRepository;

	@Override
	public ScheduledLogRepository scheduledLogRepository() {
		return scheduledLogRepository;
	}

	@Override
	public NoticeRepository noticeRepository() {
		return noticeRepository;
	}

	@Override
	public Channel channel() {
		return Channel.BOCQ;
	}

	@Override
	public void collect() {
		for (int page = 1; page <= 20; page++) {
			String indexPageName = page == 1 ? "" : "_" + page;
			String url = String.format(channel().getUrl(), indexPageName);
			logger.debugf("获取页面内容，Url：%s", url);
			try {
				Document document = Jsoup.connect(url).get();
				Elements elements = document.select(".dhy_b li");
				if (elements.isEmpty()) {
					logger.debugf("没有内容，退出：%s", url);
					break;
				}
				List<Notice> notices = Lang.list();
				for (Element element : elements) {
					String link = element.select("a").attr("href");
					Notice notice = Notice.builder()
							.channel(channel())
							.key(link.replace("/","").replace("_", "").replace(".html", "").replace(".", ""))
							.title(element.select("a").text())
							.content("")
							.url("http://www.cqcbank.com.cn"+link)
							.publishDate(date(element.select("span").text()))
							.build();
					notices.add(notice);
				}
				if (!pushNotices(notices)) {
					break;
				}
			} catch (IOException e) {
				logger.debug(e);
				break;
			}
		}
	}

	@Override
	public boolean match(Notice notice) {
		List<String> blacks = Lang.list(BLOCKED_KEY_WORDS.split("、"));
		List<String> keyWords = Lang.list(KEY_WORDS.split("、"));
		if (blacks.stream().noneMatch(key -> notice.getTitle().contains(key))
				&& blacks.stream().noneMatch(key -> notice.getContent().contains(key))) {
			return keyWords.stream().anyMatch(key -> notice.getTitle().contains(key));
		}
		return false;
	}
	
	public static void main(String[] args) {
			for (int page = 1; page <= 20; page++) {
				String indexPageName = page == 1 ? "" : "_" + page;
				String url = String.format(Channel.BOCQ.getUrl(), indexPageName);
				System.out.println("获取页面内容，Url："+url);
				try {
					Document document = Jsoup.connect(url).get();
					Elements elements = document.select(".dhy_b li");
					if (elements.isEmpty()) {
						System.out.println("没有内容，退出："+url);
						break;
					}
					List<Notice> notices = Lang.list();
					for (Element element : elements) {
						System.out.println("element:" + element);
						String link = element.select("a").attr("href");
						LocalDate pDate = LocalDate.parse(element.select("span").text());
						Notice notice = Notice.builder()
								.channel(Channel.BOCQ)
								.key(link.replace("/","").replace("_", "").replace(".html", "").replace(".", ""))
								.title(element.select("a").text())
								.content("")
								.url("http://www.cqcbank.com.cn"+link)
								.publishDate(pDate)
								.build();
						System.out.println("notice:\t"+notice.toString());
						notices.add(notice);
					}
				} catch (IOException e) {
//					logger.debug(e);
					System.out.println("IOException:" + e.getMessage());
					break;
				}
			};
//		});
	}
}
