package tech.riemann.bidding.component.impl;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;
import java.util.List;
import java.util.stream.Collectors;

import org.nutz.http.Http;
import org.nutz.http.Response;
import org.nutz.lang.Lang;
import org.nutz.lang.util.NutMap;
import org.nutz.log.Logs;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 
 */
@Component
@RequiredArgsConstructor
public class CFCPNNoticeCollector extends NoticeCollector {

	private final NoticeRepository noticeRepository;
	private final ScheduledLogRepository scheduledLogRepository;

	@Override
	public ScheduledLogRepository scheduledLogRepository() {
		return scheduledLogRepository;
	}

	@Override
	public NoticeRepository noticeRepository() {
		return noticeRepository;
	}

	@Override
	public Channel channel() {
		return Channel.CFCPN;
	}

	@Override
	public void collect() {
		for (int page = 1;; page++) {
			Response response = Http.post2(channel().getUrl(), NutMap.NEW().addv("noticeType", 1).addv("noticeState", 1)
					.addv("pageNo", page).addv("isValid", 1).addv("orderBy", "publish_time desc"), 5000, 5000);
			if (response.isOK()) {
				List<NutMap> records = Lang.map(response.getContent()).getList("rows", NutMap.class);
				if (records.isEmpty()) {
					break;
				}
				List<Notice> notices = records.stream().map(item -> {
					String content = "";
					return Notice.builder().key(item.getString("id")).channel(channel())
							.title(item.getString("noticeTitle")).content(content)
							.url(String.format(
									"http://www.cfcpn.com/jcw/sys/index/goUrl?url=modules/sys/login/detail&column=undefined&searchVal=%s",
									item.getString("id")))
							.publishDate(item.getAs("publishTime", LocalDateTime.class).toLocalDate()).build();
				}).collect(Collectors.toList());

				if (!pushNotices(notices)) {
					break;
				}
				try {
					Thread.sleep(5000);
				} catch (Exception e) {
					Logs.get().debug(e);
					break;
				}
				if (notices.stream()
						.anyMatch(item -> item.getPublishDate().isBefore(LocalDate.now().minus(2, ChronoUnit.DAYS)))) {// 早于两天的数据了,不再翻页
					break;
				}
			} else {
				Logs.get().debugf("请求发生错误,状态码为:%d", response.getStatus());
				break;
			}
		}
	}

	public static void main(String[] args) {
		for (int page = 1;; page++) {
			Response response = Http.post2(Channel.CFCPN.getUrl(),
					NutMap.NEW().addv("noticeType", 1).addv("noticeState", 1).addv("pageNo", page).addv("isValid", 1)
							.addv("orderBy", "publish_time desc"),
					5000, 5000);
			if (response.isOK()) {
				List<NutMap> records = Lang.map(response.getContent()).getList("rows", NutMap.class);
				if (records.isEmpty()) {
					Logs.get().info("records is empty!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!");
					break;
				}
				List<Notice> notices = records.stream().map(item -> {
					String content = "";
					return Notice.builder().key(item.getString("id")).channel(Channel.CFCPN)
							.title(item.getString("noticeTitle")).content(content)
							.url(String.format(
									"http://www.cfcpn.com/jcw/sys/index/goUrl?url=modules/sys/login/detail&column=undefined&searchVal=%s",
									item.getString("id")))
							.publishDate(item.getAs("publishTime", LocalDateTime.class).toLocalDate()).build();
				}).collect(Collectors.toList());

//                if (!pushNotices(notices)) {
//                    break;
//                }
				try {
					Thread.sleep(5000);
				} catch (Exception e) {
					Logs.get().info("Exception happened:" + e.toString());
					Logs.get().debug(e);
					break;
				}
				notices.stream().forEach(System.out::println);
				System.out.println("page=" + page + "" + "now():" + LocalDate.now() + "now()-5days:"
						+ LocalDate.now().minus(5, ChronoUnit.DAYS));
				if (notices.stream()
						.anyMatch(item -> item.getPublishDate().isBefore(LocalDate.now().minus(5, ChronoUnit.DAYS)))) {// 早于两天的数据了,不再翻页
					break;
				}
			} else {
				Logs.get().info("请求发生错误,状态码为:%d" + response.getStatus());
				Logs.get().debugf("请求发生错误,状态码为:%d", response.getStatus());
				break;
			}
		}
	}

}
