package tech.riemann.bidding.component.impl;

import java.io.IOException;
import java.time.LocalDate;
import java.util.List;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.nutz.lang.Lang;
import org.nutz.log.Log;
import org.nutz.log.Logs;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 
 */
@Component
@RequiredArgsConstructor
public class CQRCBNoticeCollector extends NoticeCollector {

	private final NoticeRepository noticeRepository;

	private static final Log logger = Logs.get();
	private final ScheduledLogRepository scheduledLogRepository;

	@Override
	public ScheduledLogRepository scheduledLogRepository() {
		return scheduledLogRepository;
	}

	@Override
	public NoticeRepository noticeRepository() {
		return noticeRepository;
	}

	@Override
	public Channel channel() {
		return Channel.CQRCB;
	}

	@Override
	public void collect() {
		int totalPages = getTotalPages();
		totalPages = totalPages > 20 ? 20 : totalPages;
		for (int page = 1; page <= totalPages; page++) {
			String urlSuffixStr = page == 1 ? "index" : "index_" + page + ".html";
			String url = String.format(channel().getUrl(), urlSuffixStr);
			logger.debugf("获取页面内容，Url：%s", url);
			try {
				Document document = Jsoup.connect(url).get();
				Elements elements = document.select(".sideCont ul li");
				if (elements.isEmpty()) {
					logger.debugf("没有内容，退出：%s", url);
					break;
				}
				List<Notice> notices = Lang.list();
				for (Element element : elements) {
					String link = element.select("a").attr("href");
					Notice notice = Notice.builder()
							.channel(channel())
							.key(link.replace("/","").replace(".html", ""))
							.title(element.select("a").text().replace("·",""))
							.content("")
							.url("https://www.cqrcb.com"+link)
							.publishDate(date(element.select("span").text().substring(1,11)))
							.build();
					notices.add(notice);
				}
				if (!pushNotices(notices)) {
					break;
				}
			} catch (IOException e) {
				logger.debug(e);
				break;
			}
		}
	}

	private int getTotalPages() {
		String tempUrlStr = channel().getUrl() + "/index.html";
		int totalPages;
		try {
			Document document = Jsoup.connect(tempUrlStr).get();
			Elements elements = document.select(".pages em");
			String pageRelativeStr = elements.first().select("span").text();
			int lastSlashPos = pageRelativeStr.lastIndexOf("/");
			totalPages = Integer.parseInt(pageRelativeStr.substring(lastSlashPos+1));
		} catch (Exception e) {
			// TODO: handle exception
			logger.debug(e);
			totalPages = 0;
		}
		return totalPages;
	}

	@Override
	public boolean match(Notice notice) {
		List<String> blacks = Lang.list(BLOCKED_KEY_WORDS.split("、"));
		List<String> keyWords = Lang.list(KEY_WORDS.split("、"));
		if (blacks.stream().noneMatch(key -> notice.getTitle().contains(key))
				&& blacks.stream().noneMatch(key -> notice.getContent().contains(key))) {
			return keyWords.stream().anyMatch(key -> notice.getTitle().contains(key));
		}
		return false;
	}
	
	public static void main(String[] args) {
		for (int page = 1; page <= 20; page++) {
			String urlSuffixStr = page == 1 ? "index" : "index_" + page + ".html";
			String url = String.format(Channel.CQRCB.getUrl(), urlSuffixStr);
			System.out.println("获取页面内容，Url："+url);
			try {
				Document document = Jsoup.connect(url).get();
				Elements elements = document.select(".sideCont ul li");
				if (elements.isEmpty()) {
					System.out.println("没有内容，退出："+url);
					break;
				}
				List<Notice> notices = Lang.list();
				for (Element element : elements) {
					String link = element.select("a").attr("href");
					LocalDate pDate = LocalDate.parse(element.select("span").text().substring(1,11));
					Notice notice = Notice.builder()
							.channel(Channel.CQRCB)
							.key(link.replace("/","").replace(".html", ""))
							.title(element.select("a").text().replace("·",""))
							.content("")
							.url("https://www.cqrcb.com"+link)
							.publishDate(pDate)
							.build();
					System.out.println("notice:\t"+notice.toString());
					notices.add(notice);
				}
			} catch (IOException e) {
				logger.debug(e);
				break;
			}
		}
//		});
	}
}
