package tech.riemann.bidding.component.impl;

import java.io.IOException;
import java.util.List;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.nutz.lang.Lang;
import org.nutz.log.Logs;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 
 */
@Component
@RequiredArgsConstructor
public class ChinaCcsscmNoticeCollector extends NoticeCollector {

    private final NoticeRepository noticeRepository;

    private final ScheduledLogRepository scheduledLogRepository;

    @Override
    public ScheduledLogRepository scheduledLogRepository() {
        return scheduledLogRepository;
    }

    @Override
    public NoticeRepository noticeRepository() {
        return noticeRepository;
    }

    @Override
    public Channel channel() {
        return Channel.CHINA_CCSSCM;
    }

    @Override
    public void collect() {
        for (int page = 1;; page++) {
            String url = String.format(channel().getUrl(), page);
            try {
                Document document = Jsoup.connect(url).get();
                Elements elements = document.select(".Top5 ul li");
                // 发起
                if (elements.isEmpty()) {
                    break;
                }
                List<Notice> notices = Lang.list();
                for (Element element : elements) {
                    String link = element.select("a").attr("href");
                    Notice notice = Notice.builder()
                                          .channel(channel())
                                          .key(number(link) + "")
                                          .title(element.select("a").text())
                                          .content("")
                                          .url(link.startsWith("http") ? link : "https://zb.chinaccsscm.cn" + link)
                                          .publishDate(date(element.select(".Right").text()))
                                          .build();
                    notices.add(notice);
                }
                if (!pushNotices(notices)) {
                    break;
                }
            }
            catch (IOException e) {
                Logs.get().debug(e);
                break;
            }
        }
    }

}
