package tech.riemann.bidding.component.impl;

import java.io.IOException;
import java.util.List;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.nutz.lang.Lang;
import org.nutz.log.Log;
import org.nutz.log.Logs;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 
 */
@Component
@RequiredArgsConstructor
public class GXZBNoticeCollector extends NoticeCollector {

    private final NoticeRepository noticeRepository;
    private final ScheduledLogRepository scheduledLogRepository;
    private static final Log logger = Logs.get();
    @Override
    public ScheduledLogRepository scheduledLogRepository() {
        return scheduledLogRepository;
    }

    @Override
    public NoticeRepository noticeRepository() {
        return noticeRepository;
    }

    @Override
    public Channel channel() {
        return Channel.GXZB;
    }

    @Override
    public void collect() {
            for (int page = 1; page <= 20; page++) {
                String url = String.format(channel().getUrl(), page);
                logger.debugf("获取页面内容，Url：%s", url);
                try {
                    Document document = Jsoup.connect(url).get();
                    Elements elements = document.select(".newslist>li");
                    if (elements.isEmpty()) {
                        logger.debugf("没有内容，退出：%s", url);
                        break;
                    }
                    List<Notice> notices = Lang.list();
                    for (Element element : elements) {
                        String link = element.select("a").attr("href");
                        Notice notice = Notice.builder()
                                              .channel(channel())
                                              .key(number(link.substring(link.lastIndexOf("/"))) + "")
                                              .title(element.select("a").attr("title"))
                                              .content("")
                                              .url(link)
                                              .publishDate(date(element.select(".newsDate div").text()))
                                              .build();
                        notices.add(notice);
                    }
                    if (!pushNotices(notices)) {
                        break;
                    }
                }
                catch (IOException e) {
                    logger.debug(e);
                    break;
                }
            }
    }
    public static void main(String[] args) {
		String link = "https://ebid.gxzb.com.cn/biddingBulletin/2024-04-25/46236.html";
		String number = NoticeCollector.number(link.substring(link.lastIndexOf("/")))+"";
		System.out.println(number);
	}
}
