package tech.riemann.bidding.component.impl;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;
import java.util.stream.Collectors;

import org.nutz.http.Header;
import org.nutz.http.Http;
import org.nutz.http.Response;
import org.nutz.json.Json;
import org.nutz.lang.Lang;
import org.nutz.lang.util.NutMap;
import org.nutz.log.Log;
import org.nutz.log.Logs;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 
 */
@Component
@RequiredArgsConstructor
public class PICCECNoticeCollector extends NoticeCollector {

    private final NoticeRepository noticeRepository;
    private final ScheduledLogRepository scheduledLogRepository;
    private static final Log logger = Logs.get();
    @Override
    public ScheduledLogRepository scheduledLogRepository() {
        return scheduledLogRepository;
    }

    @Override
    public NoticeRepository noticeRepository() {
        return noticeRepository;
    }

    @Override
    public Channel channel() {
        return Channel.PICCEC;
    }

    @Override
    public void collect() {
    	//供应商征集
    	//"siteId": "725", "categoryId": "211", "city": "", "county": "", "purchaseMode": ""
    	//
        for (int page = 1;; page++) {
            Response response = Http.post3(channel().getUrl(),
            							Json.toJson(NutMap.NEW()
            									.addv("dto", NutMap.NEW().addv("siteId", "725")
            																					.addv("categoryId", "211,213,214,215,216,217")
            																					.addv("city", "")
            																					.addv("county", "")
            																					.addv("purchaseMode", "")
            																					)
                                                 .addv("pageNo", page)
                                                 .addv("pageSize", 10)),
            								Header.create().asJsonContentType(),
                                           5000);
            if (response.isOK()) {
                List<NutMap> records = Lang.map(response.getContent()).getAs("res",NutMap.class).getList("rows", NutMap.class);
                if (records.isEmpty()) {
                    break;
                }
                List<Notice> notices = records.stream()
                                              .map(item -> {
                                                  String content = "";
                                                  String url=item.getString("url");
                                                  logger.debugf("获取详情页面，Url：%s", url);
                                                  return Notice.builder()
                                                               .key(Arrays.stream(url.split("/")).map(NoticeCollector::number).filter(urlitem->urlitem != 0).map(urlitem->urlitem+"").collect(Collectors.joining("-")))
                                                               .channel(channel())
                                                               .title(item.getString("title"))
                                                               .content(content)
                                                               .url("https://ec.picc.com/cms/default/webfile"+url)
                                                               .publishDate( LocalDate.parse(item.getString("publishDate"), DateTimeFormatter.ofPattern("yyyy-MM-dd'T'HH:mm:ss.SSS'+0800'", Locale.CHINESE)))
                                                               .build();
                                              })
                                              .collect(Collectors.toList());

                if (!pushNotices(notices)) {
                    break;
                }
                try {
                    Thread.sleep(5000);
                }
                catch (Exception e) {
                    Logs.get().debug(e);
                    break;
                }
                if (notices.stream().anyMatch(item -> item.getPublishDate().isBefore(LocalDate.now().minus(2, ChronoUnit.DAYS)))) {// 早于两天的数据了,不再翻页
                    break;
                }
            } else {
                Logs.get().debugf("请求发生错误,状态码为:%d", response.getStatus());
                break;
            }
        }
    }
}
