package tech.riemann.bidding.component.impl;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.List;
import java.util.stream.Collectors;

import org.nutz.http.Http;
import org.nutz.http.Response;
import org.nutz.lang.Lang;
import org.nutz.lang.util.NutMap;
import org.springframework.stereotype.Component;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import tech.riemann.bidding.component.NoticeCollector;
import tech.riemann.bidding.entity.Notice;
import tech.riemann.bidding.entity.Notice.Channel;
import tech.riemann.bidding.repository.NoticeRepository;
import tech.riemann.bidding.repository.ScheduledLogRepository;

/**
 * 中化商务采集器
 */
@Component
@RequiredArgsConstructor
public class SinoChemitcNoticeCollector extends NoticeCollector {

    private final NoticeRepository noticeRepository;
    private final ScheduledLogRepository scheduledLogRepository;

    @Override
    public ScheduledLogRepository scheduledLogRepository() {
        return scheduledLogRepository;
    }

    @Override
    public NoticeRepository noticeRepository() {
        return noticeRepository;
    }

    @Getter
    @AllArgsConstructor
    public enum Type {
        /**
         * 
         */
        ZB_YS_BG(1, "招标/预审/变更"),
        /**
         * 
         */
        FZB(3, "非招标"),
        /**
         * 
         */
        PB_ZB_JG(2, "评标/中标结果");

        int value;
        String description;
    }

    protected String url(int page, String start, String end) {
        return String.format(channel().getUrl(), page, 50, Type.ZB_YS_BG.getValue(), start, end);
    }

    @Override
    public Channel channel() {
        return Channel.SINOCHEMITC;
    }

    @Override
    public void collect() {
        for (int page = 1;; page++) {
            Response response = Http.get(url(page, LocalDate.now().minus(1, ChronoUnit.DAYS).format(DateTimeFormatter.ofPattern("yyyy-MM-dd")), ""));
            if (response.isOK()) {
                String content = response.getContent();
                List<NutMap> records = Lang.map(content).getAs("data", NutMap.class).getList("records", NutMap.class);
                if (records.isEmpty()) {
                    break;
                }
                List<Notice> notices = records.stream()
                                              .map(d -> Notice.builder()
                                                              .channel(channel())
                                                              .key(d.getString("id"))
                                                              .title(d.getString("title"))
                                                              .content(d.getString("content"))
                                                              .url(String
                                                                         .format("https://d.sinochemitc.com/#/zcnotice/detale/xq?id=%s", d.getString("id")))
                                                              .publishDate(d.getAs("publishDate", LocalDate.class))
                                                              .build())
                                              .collect(Collectors.toList());

                if (!pushNotices(notices)) {
                    break;
                }
            } else {
                break;
            }
        }
    }

    @Override
    public boolean match(Notice notice) {
        List<String> blacks = Lang.list(BLOCKED_KEY_WORDS.split("、"));
        List<String> keyWords = Lang.list(KEY_WORDS.split("、"));
        if (blacks.stream().noneMatch(key -> notice.getTitle().contains(key)) && blacks.stream().noneMatch(key -> notice.getContent().contains(key))) {
            return keyWords.stream().anyMatch(key -> notice.getTitle().contains(key));
        }
        return false;
    }

}
